@@ -56,7 +56,7 @@ def getConnectKwargs(password=None, key=os.path.join("PrivateKey.key")):
         else:
             return None
             
-def getKey(username, keyPath=os.path.join("Keys")):
+def getOrCreateKey(username, keyPath=os.path.join("Keys")):
     if not os.path.exists(keyPath):
         os.mkdir(keyPath)
     userPath = os.path.join(keyPath, username) 
@@ -148,8 +148,15 @@ def run(self, command, notRecord=False, **kwargs):
             self.commands.append(c)
         else:
             self.commands = [c]
-        
-    return self._run(self._remote_runner(), command, **kwargs)
+            
+    if not "encoding" in kwargs:
+        kwargs["encoding"] = "utf8"
+    
+    # with open("test.log", 'a+') as f:  
+        # result = self._run(self._remote_runner(), command, out_stream=f, err_stream=f, **kwargs)
+    result = self._run(self._remote_runner(), command, **kwargs)
+    
+    return result
     
 def recordLogs(self):
     # get user
